//
//  GLViewController.m
//  OpenGL-test1
//
//  Created by Paul Solt on 12/9/09.
//  Copyright RIT 2009. All rights reserved.
//

#import "GLViewController.h"
#import "ConstantsAndMacros.h"
#import "OpenGLCommon.h"


@implementation GLViewController
- (void)drawView:(UIView *)theView
{
	static GLfloat rotation = 0.0;	// Simple static variable to control rotation
    
	// Demonstrates creating memory on stack and heap. Generally you'll
	// create vertex/color arrays on the heap and keep track of the memory.
	
	// Vertices are created on the stack
	Vertex3D v1 = Vertex3DMake(5.0, 5.0, -3.0);
	Vertex3D v2 = Vertex3DMake(0.0, 5.0, -3.0);
	Vertex3D v3 = Vertex3DMake(1.0, 0.0, -3.0);
	Triangle3D triangle = Triangle3DMake(v3, v2, v1);
		
	// Colors are created on the heap
	Color3D *colors = malloc(sizeof(Color3D) * 3);
    Color3DSet(&colors[0], 1.0, 0.0, 0.0, 1.0);
    Color3DSet(&colors[1], 0.0, 1.0, 0.0, 1.0);
    Color3DSet(&colors[2], 0.0, 0.0, 1.0, 1.0);
    
	rotation = rotation + 1;
	
    glLoadIdentity();	// Resets the OpenGL Matrix state
	glClearColor(0.7, 0.7, 0.7, 1.0);
    glClear(GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
    
	// Rotate the view by the rotation
	glRotatef(rotation, 0.0, 0.0, 1.0);	
	
    
	// Enable Vertex and Color arrays
	glEnableClientState(GL_VERTEX_ARRAY);
    glEnableClientState(GL_COLOR_ARRAY);
    
	// Set the vertex array
	glVertexPointer(3, GL_FLOAT, 0, &triangle); // use & for the address of the array
    
	// Set the color array
	glColorPointer(4, GL_FLOAT, 0, colors);	// Pointer doesn't need & for memory address
    
	// Draw the triangle using the Vertex and Color pointer
	glDrawArrays(GL_TRIANGLES, 0, 9);
	
    glDisableClientState(GL_VERTEX_ARRAY);
    glDisableClientState(GL_COLOR_ARRAY);
    
	// Free the dynamically allocated memory
    if (colors != NULL)
        free(colors);
}
	

//  Sets up the OpenGL view window to be the range (-10,-10) to (10,10) with the
// origin at (0,0)
-(void)setupView:(GLView*)view
{
	const GLfloat zNear = 0.01, zFar = 1000.0; 
	glEnable(GL_DEPTH_TEST);
	glMatrixMode(GL_PROJECTION); 
	CGRect rect = view.bounds; 
	
	
	glOrthof(-10,	// Left
			 10,	// Right
			 -10,	// Bottom
			 10,	// Top
			 zNear, 
			 zFar);
	glViewport(0, 0, rect.size.width, rect.size.height);  
	glMatrixMode(GL_MODELVIEW);
	
	glLoadIdentity(); 
}
- (void)dealloc 
{
    [super dealloc];
}
@end
